@@ -113,7 +113,7 @@ def generate_request(r:common.Result) -> str:
 </div>
 """
 
-def generate_final(switchs:list, nb_ok:int, nb_tests:int) -> str:
+def generate_final(switchs:tuple, nb_ok:int, nb_tests:int) -> str:
     switch = ", ".join(switchs)
     title = f"<title>{switch or ''} {nb_ok}/{nb_tests}</title>"
     return f"<div class='final'>{switch+'<br>' if switch else ''}{nb_ok}/{nb_tests}</div>" + title
